package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.ChargeDetailsMapper;
import com.ruoyi.system.domain.ChargeDetails;
import com.ruoyi.system.service.IChargeDetailsService;

/**
 * 工单收费详情Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-12
 */
@Service
public class ChargeDetailsServiceImpl implements IChargeDetailsService 
{
    @Autowired
    private ChargeDetailsMapper chargeDetailsMapper;

    /**
     * 查询工单收费详情
     * 
     * @param id 工单收费详情主键
     * @return 工单收费详情
     */
    @Override
    public ChargeDetails selectChargeDetailsById(Long id)
    {
        return chargeDetailsMapper.selectChargeDetailsById(id);
    }

    /**
     * 查询工单收费详情列表
     * 
     * @param chargeDetails 工单收费详情
     * @return 工单收费详情
     */
    @Override
    public List<ChargeDetails> selectChargeDetailsList(ChargeDetails chargeDetails)
    {
        return chargeDetailsMapper.selectChargeDetailsList(chargeDetails);
    }

    /**
     * 新增工单收费详情
     * 
     * @param chargeDetails 工单收费详情
     * @return 结果
     */
    @Override
    public int insertChargeDetails(ChargeDetails chargeDetails)
    {
        return chargeDetailsMapper.insertChargeDetails(chargeDetails);
    }

    /**
     * 修改工单收费详情
     * 
     * @param chargeDetails 工单收费详情
     * @return 结果
     */
    @Override
    public int updateChargeDetails(ChargeDetails chargeDetails)
    {
        return chargeDetailsMapper.updateChargeDetails(chargeDetails);
    }

    /**
     * 批量删除工单收费详情
     * 
     * @param ids 需要删除的工单收费详情主键
     * @return 结果
     */
    @Override
    public int deleteChargeDetailsByIds(Long[] ids)
    {
        return chargeDetailsMapper.deleteChargeDetailsByIds(ids);
    }

    /**
     * 删除工单收费详情信息
     * 
     * @param id 工单收费详情主键
     * @return 结果
     */
    @Override
    public int deleteChargeDetailsById(Long id)
    {
        return chargeDetailsMapper.deleteChargeDetailsById(id);
    }
}
