package com.ruoyi.web.controller.work;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ChargeDetails;
import com.ruoyi.system.service.IChargeDetailsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 工单收费详情Controller
 * 
 * @author ruoyi
 * @date 2025-05-12
 */
@RestController
@RequestMapping("/charge/details")
public class ChargeDetailsController extends BaseController
{
    @Autowired
    private IChargeDetailsService chargeDetailsService;

    /**
     * 查询工单收费详情列表
     */
    @PreAuthorize("@ss.hasPermi('charge:details:list')")
    @GetMapping("/list")
    public TableDataInfo list(ChargeDetails chargeDetails)
    {
        startPage();
        List<ChargeDetails> list = chargeDetailsService.selectChargeDetailsList(chargeDetails);
        return getDataTable(list);
    }

    /**
     * 导出工单收费详情列表
     */
    @PreAuthorize("@ss.hasPermi('charge:details:export')")
    @Log(title = "工单收费详情", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ChargeDetails chargeDetails)
    {
        List<ChargeDetails> list = chargeDetailsService.selectChargeDetailsList(chargeDetails);
        ExcelUtil<ChargeDetails> util = new ExcelUtil<ChargeDetails>(ChargeDetails.class);
        util.exportExcel(response, list, "工单收费详情数据");
    }

    /**
     * 获取工单收费详情详细信息
     */
    @PreAuthorize("@ss.hasPermi('charge:details:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(chargeDetailsService.selectChargeDetailsById(id));
    }

    /**
     * 新增工单收费详情
     */
    @PreAuthorize("@ss.hasPermi('charge:details:add')")
    @Log(title = "工单收费详情", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ChargeDetails chargeDetails)
    {
        return toAjax(chargeDetailsService.insertChargeDetails(chargeDetails));
    }

    /**
     * 修改工单收费详情
     */
    @PreAuthorize("@ss.hasPermi('charge:details:edit')")
    @Log(title = "工单收费详情", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody ChargeDetails chargeDetails)
    {
        return toAjax(chargeDetailsService.updateChargeDetails(chargeDetails));
    }

    /**
     * 删除工单收费详情
     */
    @PreAuthorize("@ss.hasPermi('charge:details:remove')")
    @Log(title = "工单收费详情", businessType = BusinessType.DELETE)
    @GetMapping("/delete/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(chargeDetailsService.deleteChargeDetailsByIds(ids));
    }
}
